@@ -1,5 +1,5 @@
 use derive_more::Display;
-use poem::{get, http::StatusCode, route, Response, ResponseError, Server};
+use poem::{get, http::StatusCode, route, Error, Response, ResponseError, Result, Server};
 
 #[derive(Debug, Display)]
 struct CustomError;
@@ -13,8 +13,8 @@ impl ResponseError for CustomError {
 }
 
 #[get]
-fn index() -> Result<String, CustomError> {
-    Err(CustomError)
+fn index() -> Result<String> {
+    Err(Error::new(CustomError))
 }
 
 #[tokio::main]
