@@ -1,9 +1,9 @@
-use poem::{get, handler, middleware::Tracing, route, web::Path, EndpointExt, Server};
+use poem::{get, middleware::Tracing, route, web::Path, EndpointExt, Server};
 use tracing_subscriber::{
     fmt, fmt::format::FmtSpan, layer::SubscriberExt, util::SubscriberInitExt, EnvFilter,
 };
 
-#[handler]
+#[get]
 fn hello(Path(name): Path<String>) -> String {
     format!("hello: {}", name)
 }
@@ -23,7 +23,7 @@ async fn main() {
         )
         .init();
 
-    let app = route().at("/hello/:name", get(hello)).with(Tracing);
+    let app = route().at("/hello/:name", hello).with(Tracing);
 
     let server = Server::bind("127.0.0.1:3000").await.unwrap();
     server.run(app).await.unwrap();
