@@ -1,4 +1,4 @@
-use crate::{http::StatusCode, Endpoint, Error, Request, Response};
+use crate::{http::StatusCode, Endpoint, Request, Response};
 
 /// Endpoint for the [`or`](super::EndpointExt::or) method.
 pub struct Or<A, B>(A, B);
@@ -15,13 +15,13 @@ where
     A: Endpoint,
     B: Endpoint,
 {
-    async fn call(&self, req: Request) -> crate::Result<Response> {
+    async fn call(&self, req: Request) -> Response {
         return if self.0.check(&req) {
             self.0.call(req).await
         } else if self.1.check(&req) {
             self.1.call(req).await
         } else {
-            Err(Error::status(StatusCode::NOT_FOUND))
+            StatusCode::NOT_FOUND.into()
         };
     }
 }
