@@ -4,6 +4,7 @@ mod add_data;
 #[cfg(feature = "compression")]
 mod compression;
 mod cors;
+mod set_header;
 #[cfg(feature = "tracing")]
 mod tracing;
 
@@ -11,6 +12,7 @@ pub use add_data::AddData;
 #[cfg(feature = "compression")]
 pub use compression::{Compression, CompressionAlgo};
 pub use cors::Cors;
+pub use set_header::SetHeader;
 
 #[cfg(feature = "tracing")]
 pub use self::tracing::Tracing;
