@@ -9,7 +9,7 @@ use crate::{
         header::{self, HeaderMap, HeaderName, HeaderValue},
         Extensions, StatusCode, Version,
     },
-    Body,
+    Body, Error,
 };
 
 /// Represents an HTTP response.
@@ -38,6 +38,24 @@ impl<T: Into<Body>> From<T> for Response {
     }
 }
 
+impl From<StatusCode> for Response {
+    fn from(status: StatusCode) -> Self {
+        Response::builder().status(status).finish()
+    }
+}
+
+impl From<Error> for Response {
+    fn from(err: Error) -> Self {
+        err.as_response()
+    }
+}
+
+impl<T: Into<Body>> From<(StatusCode, T)> for Response {
+    fn from((status, body): (StatusCode, T)) -> Self {
+        Response::builder().status(status).body(body.into())
+    }
+}
+
 impl Response {
     pub(crate) fn into_hyper_response(mut self) -> hyper::Response<hyper::Body> {
         let mut resp = hyper::Response::new(std::mem::take(&mut self.body).0);
